@@ -76,6 +76,8 @@ class Model:
     def trainFromImageAndSeeds(self, data, seeds, cl):
         """
         This method allows computes feature vector and train model.
+
+        :cl: scalar index number of class
         """
         fv = self.createFV(data, seeds, cl)
         self.train(fv, cl)
@@ -700,7 +702,7 @@ class ImageGraphCut:
             try:
                 # because of negative problem is as 1 segmented background and
                 # as 0 is segmented foreground
-                import thresholding_functions
+                from lisa import thresholding_functions
                 newData = thresholding_functions.getPriorityObjects(
                     (1 - res_segm),
                     nObj=-1,
